==> com.liferay.journal.web-3.0.20.jar: META-INF/resources/js/FeedsManagementToolbarDefaultEventHandler.es.js <==
"use strict";

Liferay.Loader.define("journal-web@3.0.20/js/FeedsManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web/liferay/DefaultEventHandler.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  var _DefaultEventHandler2 = _interopRequireDefault(require("frontend-js-web/liferay/DefaultEventHandler.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var FeedsManagementToolbarDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(FeedsManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function FeedsManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, FeedsManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(FeedsManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(FeedsManagementToolbarDefaultEventHandler, [{
      key: "deleteFeeds",
      value: function deleteFeeds() {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-this'))) {
          submitForm(this.one('#fm'));
        }
      }
    }]);

    return FeedsManagementToolbarDefaultEventHandler;
  }(_DefaultEventHandler2.default);

  var _default = FeedsManagementToolbarDefaultEventHandler;
  exports.default = _default;
  //# sourceMappingURL=FeedsManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=FeedsManagementToolbarDefaultEventHandler.es.js.map

==> com.liferay.journal.web-3.0.48.jar: META-INF/resources/js/FeedsManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("journal-web@3.0.48/js/FeedsManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _frontendJsWeb = require("frontend-js-web");

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var FeedsManagementToolbarDefaultEventHandler =
  /*#__PURE__*/
  function (_DefaultEventHandler) {
    _inherits(FeedsManagementToolbarDefaultEventHandler, _DefaultEventHandler);

    function FeedsManagementToolbarDefaultEventHandler() {
      _classCallCheck(this, FeedsManagementToolbarDefaultEventHandler);

      return _possibleConstructorReturn(this, _getPrototypeOf(FeedsManagementToolbarDefaultEventHandler).apply(this, arguments));
    }

    _createClass(FeedsManagementToolbarDefaultEventHandler, [{
      key: "deleteFeeds",
      value: function deleteFeeds() {
        if (confirm(Liferay.Language.get('are-you-sure-you-want-to-delete-this'))) {
          submitForm(this.one('#fm'));
        }
      }
    }]);

    return FeedsManagementToolbarDefaultEventHandler;
  }(_frontendJsWeb.DefaultEventHandler);

  var _default = FeedsManagementToolbarDefaultEventHandler;
  exports["default"] = _default;
  //# sourceMappingURL=FeedsManagementToolbarDefaultEventHandler.es.js.map
});
//# sourceMappingURL=FeedsManagementToolbarDefaultEventHandler.es.js.map
